@@ -75,7 +75,7 @@ class Domoticz(IPlugin):
 		if jsonInput['outcome']['entities']['local_search_query']['value'] :
 			local = jsonInput['outcome']['entities']['local_search_query']['value']
 		else:
-			local_search_query = "pas de local_search_query"
+			local = "pas de local_search_query"
 			bodies = ""
 #
 		idex= local + " " + location +  "_"
@@ -89,7 +89,6 @@ class Domoticz(IPlugin):
 				log.msg("BODIES  :  %s" % (bodies))
 				log.msg("local  :  %s" % (local))
 				log.msg("number  :  %s" % (int(rs['idx'])))
-				
 				resp = requests.get ('http://192.168.0.3:8080/json.htm?type=devices&filter=temp&used=true&order=Name')
 				jsonreq = resp.json()
 				for rt in jsonreq['result'] :
@@ -98,11 +97,11 @@ class Domoticz(IPlugin):
 						log.msg("*********  jsonreq - batlevel   :  %s" % (rt['BatteryLevel']))
 						log.msg("*********  jsonreq - Temp   :  %s" % (rt['Temp']))
 #						log.msg("*********  jsonreq - Name   :  %s" % (rt['Name']))
-						log.msg("*********  jsonreq - Data   :  %s" % (rt['Data']))
+						log.msg("*********  jsonreq - Data   :  %s" % (rt['BatteryLevel']))
 						if local == "temperature" :
-							bodies = "la temperature a été trouvée"
+							bodies = "la temperature a été trouvée et elle est de %s degré" % (rt['Temp'])
 						if local == "batterie" :
-							bodies = "le niveau de batterie a été trouvé"
+							bodies = "le niveau de batterie a été trouvé et elle est de %s " % (rt['BatteryLevel'])
 		if bodies == "":
 			bodies = "j'ai rien compris aux devices"
 		return {"plugin": "Domoticz",
